==> libpdssn-0.03.0.tar.gz: libpdssn-0.03.0/src/headers/pds/pdssnglobal.h <==
/*
 * pdssnglobal.h
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

/** \file pdssnglobal.h
 *  \author Fernando Pujaico Rivera
 *  \date 31-12-2011
 *  \brief Variables globales y definciones de la biblioteca pdssn.
 *  
 *  <br><br>Aquí Estarán definidas las variables globales que serán usadas en
 *  toda la biblioteca pdssn.
 */

#ifndef __PDSSNGLOBAL_H__
#define __PDSSNGLOBAL_H__

#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif 

/** \defgroup PdsSnGlobalGroup Definiciones globales de PdsSn.
 * @{
 */

/*! Defino el tipo de variable real como PdsSnReal.
 *  \ingroup PdsSnGlobalGroup
 */
typedef float PdsSnReal;

/*! Defino el tipo de variable entero como PdsSnInteger.
 *  \ingroup PdsSnGlobalGroup
 */
typedef int PdsSnInteger;

/*! Defino el tipo de variable natural (incluye cero) como PdsSnNatural.
 *  \ingroup PdsSnGlobalGroup
 */
typedef unsigned int PdsSnNatural;


/**
 * @}
 */


#ifdef __cplusplus
}
#endif 

#endif /* __PDSSNGLOBAL_H__ */

==> libpdssn-0.04.0.tar.gz: libpdssn-0.04.0/src/headers/pds/pdssnglobal.h <==
/*
 * pdssnglobal.h
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

/** \file pdssnglobal.h
 *  \author Fernando Pujaico Rivera
 *  \date 31-12-2011
 *  \brief Variables globales y definciones de la biblioteca pdssn.
 *  
 *  <br><br>Aquí Estarán definidas las variables globales que serán usadas en
 *  toda la biblioteca pdssn.
 */

#ifndef __PDSSNGLOBAL_H__
#define __PDSSNGLOBAL_H__

#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif 

/** \defgroup PdsSnGlobalGroup Definiciones globales.
 *  \brief Definiciones de de variables globales.
 *
 * @{
 */

/*! Defino el tipo de variable real como PdsSnReal.
 *  \ingroup PdsSnGlobalGroup
 */
typedef float PdsSnReal;

/*! Defino el tipo de variable entero como PdsSnInteger.
 *  \ingroup PdsSnGlobalGroup
 */
typedef int PdsSnInteger;

/*! Defino el tipo de variable natural (incluye cero) como PdsSnNatural.
 *  \ingroup PdsSnGlobalGroup
 */
typedef unsigned int PdsSnNatural;


/**
 * @}
 */


#ifdef __cplusplus
}
#endif 

#endif /* __PDSSNGLOBAL_H__ */
